@@ -26,9 +26,8 @@
 #' @author Luigi Ranghetti, phD (2020) \email{luigi@@ranghetti.info}
 #' @author Lorenzo Busetto, phD (2019) \email{lbusett@@gmail.com}
 #' @note License: GPL 3.0
-#' @importFrom httr GET RETRY authenticate progress write_disk
+#' @importFrom httr RETRY authenticate progress write_disk
 #' @importFrom foreach foreach "%do%"
-#' @importFrom tools md5sum
 #' @export
 #'
 #' @examples
@@ -188,13 +187,13 @@ s2_download <- function(
         } else {
           file(out_bar_path <- tempfile(), open = "a")
         }
-        download <- httr::RETRY(
+        download <- RETRY(
           verb = "GET",
           url = as.character(link),
-          config = httr::authenticate(creds[1], creds[2]),
-          times = 10,
-          httr::progress(con = if (length(out_bar) > 0) {out_bar} else {stdout()}),
-          httr::write_disk(zip_path, overwrite = TRUE)
+          config = authenticate(creds[1], creds[2]),
+          times = 5, pause_cap = 8,
+          progress(con = if (length(out_bar) > 0) {out_bar} else {stdout()}),
+          write_disk(zip_path, overwrite = TRUE)
         )
         if (length(out_bar) > 0) {
           close(out_bar)
@@ -245,20 +244,26 @@ s2_download <- function(
       } else {
         # check md5
         check_md5 <- tryCatch({
-          sel_md5 <- httr::GET(
+          requireNamespace("tools")
+          sel_md5 <- RETRY(
+            verb = "GET",
             url = gsub("\\$value$", "Checksum/Value/$value", as.character(link)),
-            config = httr::authenticate(creds[1], creds[2]),
-            httr::write_disk(md5file <- tempfile(), overwrite = TRUE)
+            config = authenticate(creds[1], creds[2]),
+            write_disk(md5file <- tempfile(), overwrite = TRUE)
           )
-          md5 <- toupper(readLines(md5file, warn = FALSE)) == toupper(md5sum(zip_path))
+          md5 <- toupper(readLines(md5file, warn = FALSE)) == 
+            toupper(tools::md5sum(zip_path))
           file.remove(md5file)
           md5
         }, error = function(e) {logical(0)})
         if (any(!check_md5 %in% c(TRUE, FALSE), length(check_md5) == 0)) {
           print_message(
             type = "warning",
-            "File ", names(link), " cannot be checked. ",
-            "Please verify if the download was successful."
+            "File ", names(link), " cannot be checked",
+            if (!requireNamespace("tools", quietly = TRUE)) {
+              "(package \"tools\" needs to be installed)"
+            },
+            ". Please verify if the download was successful."
           )
         } else if (!check_md5) {
           file.remove(zip_path)
