@@ -29,11 +29,14 @@
 #'  format recognised by GDAL). Default is to maintain each input format.
 #' @param compress (optional) In the case a GTiff format is
 #'  present, the compression indicated with this parameter is used.
+#' @param bigtiff (optional) Logical: if TRUE, the creation of a BigTIFF is
+#'  forced (default is FALSE).
+#'  This option is used only in the case a GTiff format was chosen. 
 #' @param vrt_rel_paths (optional) Logical: if TRUE (default on Linux),
 #'  the paths present in the VRT output file are relative to the VRT position;
 #'  if FALSE (default on Windows), they are absolute.
 #'  This takes effect only with `format = "VRT"`.
-#' @param out_crs (optional) proj4string (character) of the output CRS
+#' @param out_crs (optional) output CRS, in any format accepted by [st_crs2]
 #'  (default: the CRS of the first input file). The tiles with CRS different
 #'  from `out_crs` will be reprojected (and a warning returned).
 #' @param parallel (optional) Logical: if TRUE, the function is run using parallel
@@ -49,11 +52,11 @@
 #'  (it is used when the function is called by `sen2r()`).
 #' @return A vector with the names of the merged products (just created or
 #'  already existing).
-#' @importFrom magrittr "%>%"
 #' @importFrom jsonlite fromJSON
 #' @importFrom foreach foreach "%do%" "%dopar%"
 #' @importFrom doParallel registerDoParallel
 #' @importFrom parallel makeCluster stopCluster detectCores
+#' @importFrom sf st_as_text
 #' @import data.table
 #' @export
 #' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
@@ -67,8 +70,9 @@ s2_merge <- function(infiles,
                      rmtmp=TRUE,
                      format=NA,
                      compress="DEFLATE",
+                     bigtiff=FALSE,
                      vrt_rel_paths=NA,
-                     out_crs="",
+                     out_crs=NA,
                      parallel = FALSE,
                      overwrite=FALSE,
                      .log_message=NA,
@@ -105,7 +109,7 @@ s2_merge <- function(infiles,
   # get metadata
   infiles_meta_gdal <- raster_metadata(infiles, c("outformat", "proj"), format = "data.table")
   infiles_meta$format <- infiles_meta_gdal$outformat
-  infiles_meta$proj4string <- infiles_meta_gdal$proj
+  infiles_meta$proj <- infiles_meta_gdal$proj
   # infiles_meta$NAflag <- sapply(infiles_meta_gdal[3,], function(x) {
   #   if (x[1,"hasNoDataValue"]==TRUE) {
   #     x[1,"NoDataValue"]
@@ -125,22 +129,22 @@ s2_merge <- function(infiles,
   # }
   
   # if utm zones differ from the selected utm zone, show a warning
-  if (out_crs=="") {
+  if (missing(out_crs)) {
     print_message(
       type="message",
-      "Using projection \"",infiles_meta$proj4string[1],"\".")
-    out_crs <- infiles_meta$proj4string[1]
+      "Using projection \"",infiles_meta$proj[1],"\".")
+    out_crs <- infiles_meta$proj[1]
   }
   
   # vector which identifies, for each infiles, if its projection is
   # different or not from out_crs
-  diffcrs <- sapply(infiles_meta$proj4string, function(x) {
+  diffcrs <- sapply(infiles_meta$proj, function(x) {
     st_crs2(x) != st_crs2(out_crs)
     # !compareCRS(CRS(x), CRS(out_crs))
   })
   
   # Check out_crs
-  out_crs <- st_crs2(out_crs)$proj4string
+  out_crs <- st_crs2(out_crs)
   # check the projections of input files
   if (any(diffcrs)) {
     print_message(
@@ -174,8 +178,15 @@ s2_merge <- function(infiles,
   }
   dir.create(tmpdir, recursive=FALSE, showWarnings=FALSE)
   
-  # create outdir if not existing
+  # create outdir if not existing (and dirname(outdir) exists)
   suppressWarnings(outdir <- expand_path(outdir, parent=comsub(infiles,"/"), silent=TRUE))
+  if (!dir.exists(dirname(outdir))) {
+    print_message(
+      type = "error",
+      "The parent folder of 'outdir' (",outdir,") does not exist; ",
+      "please create it."
+    )
+  }
   dir.create(outdir, recursive=FALSE, showWarnings=FALSE)
   
   # if out_crs is different from the projection of all input files,
@@ -183,15 +194,25 @@ s2_merge <- function(infiles,
   # otherwise, use the first non-reprojected file.
   if (all(diffcrs)) {
     ref_file <- file.path(tmpdir,".ref_grid.vrt")
+    out_crs_string <- if (!is.na(out_crs$epsg)) {
+      paste0("EPSG:",out_crs$epsg)
+    } else {
+      writeLines(
+        st_as_text_2(out_crs),
+        out_crs_path <- tempfile(pattern = "out_crs_", tmpdir = tmpdir, fileext = ".prj")
+      )
+      out_crs_path
+    }
     system(
       paste0(
         binpaths$gdalwarp," ",
         "-overwrite ",
-        "-s_srs \"",infiles_meta[1,"proj4string"],"\" ",
-        "-t_srs \"",out_crs,"\" ",
+        "-s_srs \"",infiles_meta[1,"proj"],"\" ",
+        "-t_srs \"",out_crs_string,"\" ",
         "-of VRT ",
         "\"",infiles[1],"\" ",
-        "\"",ref_file,"\""),
+        "\"",ref_file,"\""
+      ),
       intern = Sys.info()["sysname"] == "Windows"
     )
   } else {
@@ -304,11 +325,14 @@ s2_merge <- function(infiles,
                "_reproj.vrt",
                basename(sel_infiles[sel_diffcrs][i]))
         )
-        gdalwarp_grid(srcfiles = sel_infiles[sel_diffcrs][i],
-                      dstfiles = reproj_vrt,
-                      ref = ref_file,
-                      of = "VRT",
-                      r = "near")
+        gdalwarp_grid(
+          srcfiles = sel_infiles[sel_diffcrs][i],
+          dstfiles = reproj_vrt,
+          ref = ref_file,
+          of = "VRT",
+          tmpdir = sel_tmpdir,
+          r = "near"
+        )
         if (vrt_rel_paths) {gdal_abs2rel(reproj_vrt)}
         
         # replace input file path with intermediate
@@ -336,6 +360,7 @@ s2_merge <- function(infiles,
           binpaths$gdal_translate," ",
           "-of ",sel_outformat," ",
           if (sel_outformat=="GTiff") {paste0("-co COMPRESS=",toupper(compress)," ")},
+          if (sel_outformat=="GTiff" & bigtiff==TRUE) {paste0("-co BIGTIFF=YES ")},
           "\"",merged_vrt,"\" ",
           "\"",file.path(out_subdir,sel_outfile),"\" "),
         intern = Sys.info()["sysname"] == "Windows"
