@@ -5,7 +5,7 @@ testthat::skip_on_travis()
 # NOTE: these tests require a high amount of time (depending on connection speed),
 # so the download is disabled by default if SAFE archives are already present.
 # To perform the test also on download, replace 'test_download = FALSE' with 'TRUE'.
-test_download = FALSE
+test_download = TRUE
 
 safe_dir <- file.path(dirname(attr(load_binpaths(), "path")), "safe")
 dir.create(safe_dir, showWarnings = FALSE)
@@ -20,10 +20,10 @@ testthat::test_that(
     #   level = "auto"
     # )
     s2_l2a_list <- c(
-      "S2A_MSIL2A_20170703T101021_N0205_R022_T32TNS_20170703T101041.SAFE" = 
-        "https://scihub.copernicus.eu/apihub/odata/v1/Products('50f281e9-26ed-4d52-b394-18a4040c88b7')/$value",
-      "S2A_MSIL2A_20170703T101021_N0205_R022_T32TNR_20170703T101041.SAFE" = 
-        "https://scihub.copernicus.eu/apihub/odata/v1/Products('b4b6b897-a03a-4f3c-b78d-974066574aed')/$value"
+      "S2A_MSIL2A_20190723T101031_N0213_R022_T32TNS_20190723T125722.SAFE" = 
+        "https://scihub.copernicus.eu/apihub/odata/v1/Products('49d80ae3-12e3-4069-a813-ae4b0257592b')/$value",
+      "S2A_MSIL2A_20190723T101031_N0213_R022_T32TNR_20190723T125722.SAFE" = 
+        "https://scihub.copernicus.eu/apihub/odata/v1/Products('52b43ef1-9a43-4726-a833-9fabeb1a3329')/$value"
     )
     suppressWarnings(s2_l2a_downloaded <- s2_download(
       s2_l2a_list,
@@ -40,9 +40,9 @@ testthat::test_that(
       list.files(
         file.path(
           exp_outsafe_1[grepl("32TNR", exp_outsafe_1)],
-          "GRANULE/L2A_T32TNR_A010601_20170703T101041/IMG_DATA/R10m"
+          "GRANULE/L2A_T32TNR_A021326_20190723T101347/IMG_DATA/R10m"
         ),
-        "T32TNR_20170703T101021_B02", full.names = TRUE
+        "T32TNR_20190723T101031_B02_10m", full.names = TRUE
       ), format = "list"
     )[[1]]
     testthat::expect_equal(exp_meta_ex$size, c("x" = 10980, "y" = 10980))
@@ -66,11 +66,11 @@ testthat::test_that(
       )
       testthat::expect_equal(
         dirname(safe_metadata1$xml_granules), 
-        file.path(exp_outsafe_1,paste0("GRANULE/L2A_T",c("32TNS","32TNR"),"_A010601_20170703T101041"))
+        file.path(exp_outsafe_1,paste0("GRANULE/L2A_T",c("32TNS","32TNR"),"_A021326_20190723T101347"))
       )
       testthat::expect_equal(safe_metadata1$mission, rep("2A",2))
       testthat::expect_equal(safe_metadata1$level, rep("2A",2))
-      testthat::expect_equal(as.Date(safe_metadata1$sensing_datetime), rep(as.Date("2017-07-03"),2))
+      testthat::expect_equal(as.Date(safe_metadata1$sensing_datetime), rep(as.Date("2019-07-23"),2))
       testthat::expect_equal(safe_metadata1$id_orbit, rep("022",2))
       testthat::expect_equal(safe_metadata1$id_tile, c("32TNS","32TNR"))
       testthat::expect_equal(safe_metadata1$utm, rep("32N",2))
@@ -118,10 +118,10 @@ testthat::test_that(
     #   level = "L1C"
     # )
     s2_l1c_list <- c(
-      "S2A_MSIL1C_20190703T101031_N0207_R022_T32TNR_20190703T122502.SAFE" = 
-        "https://scihub.copernicus.eu/apihub/odata/v1/Products('83ccd36c-226a-4730-9602-b9bb0fc6bcce')/$value",
-      "S2A_MSIL1C_20190703T101031_N0207_R022_T32TNS_20190703T122502.SAFE" = 
-        "https://scihub.copernicus.eu/apihub/odata/v1/Products('304840b4-10ab-42c6-9809-b3664d6e4f50')/$value"
+      "S2A_MSIL1C_20190723T101031_N0208_R022_T32TNR_20190723T121220.SAFE" = 
+        "https://scihub.copernicus.eu/apihub/odata/v1/Products('13fef7f9-3a85-49cd-9f39-4b5649e597ba')/$value",
+      "S2A_MSIL1C_20190723T101031_N0208_R022_T32TNS_20190723T121220.SAFE" = 
+        "https://scihub.copernicus.eu/apihub/odata/v1/Products('19bbde60-992b-423d-8dea-a5e0ac7715fc')/$value"
     )
     suppressWarnings(s2_l1c_downloaded <- s2_download(
       s2_l1c_list,
@@ -138,9 +138,9 @@ testthat::test_that(
       list.files(
         file.path(
           exp_outsafe_2[grepl("32TNR", exp_outsafe_2)],
-          "GRANULE/L1C_T32TNR_A021040_20190703T101051/IMG_DATA"
+          "GRANULE/L1C_T32TNR_A021326_20190723T101347/IMG_DATA"
         ),
-        "T32TNR_20190703T101031_B01", full.names = TRUE
+        "T32TNR_20190723T101031_B01", full.names = TRUE
       ), format = "list"
     )[[1]]
     
@@ -167,7 +167,7 @@ testthat::test_that(
       )
       testthat::expect_equal(
         dirname(as.vector(unlist(safe_metadata$xml_granules))), 
-        file.path(exp_outsafe_2,paste0("GRANULE/L1C_T",c("32TNR","32TNS"),"_A021040_20190703T101051"))
+        file.path(exp_outsafe_2,paste0("GRANULE/L1C_T",c("32TNR","32TNS"),"_A021326_20190723T101347"))
       )
       testthat::expect_equal(unique(safe_metadata$mission), "2A")
       testthat::expect_equal(unique(safe_metadata$level), "1C")
